@@ -2,6 +2,7 @@ import logging
 import time
 
 from .base import BaseAction
+from ..env import watchers
 from ..errors import UnitErrors
 from ..utils import ErrorExit
 
@@ -158,27 +159,32 @@ class Importer(BaseAction):
             return True
         return False
 
-    def wait_for_units(self, ignore_error=False):
+    def wait_for_units(self, ignore_errors=False):
         timeout = self.options.timeout - (time.time() - self.start_time)
         if timeout < 0:
             self.log.error("Reached deployment timeout.. exiting")
             raise ErrorExit()
-        try:
-            self.env.wait_for_units(
-                int(timeout), watch=self.options.watch, no_exit=ignore_error)
-        except UnitErrors:
-            if not ignore_error:
-                raise
+        # Set up the callback to be called in case of unit errors: if
+        # ignore_errors is True errors are just logged, otherwise we exit the
+        # program.
+        if ignore_errors:
+            on_errors = watchers.log_on_errors(self.env)
+        else:
+            on_errors = watchers.exit_on_errors(self.env)
+        self.env.wait_for_units(
+            int(timeout), watch=self.options.watch,
+            services=self.deployment.get_service_names(), on_errors=on_errors)
 
     def run(self):
+        options = self.options
         self.start_time = time.time()
-        if self.options.bootstrap:
+        if options.bootstrap:
             self.env.bootstrap()
         self.env.connect()
 
         # Get charms
         self.get_charms()
-        if self.options.branch_only:
+        if options.branch_only:
             return
 
         self.deploy_services()
@@ -189,20 +195,21 @@ class Importer(BaseAction):
         time.sleep(5.1)
         self.add_units()
 
+        ignore_errors = bool(options.retry_count) or options.ignore_errors
         self.log.debug("Waiting for units before adding relations")
-        self.wait_for_units()
+        self.wait_for_units(ignore_errors=ignore_errors)
 
         rels_created = self.add_relations()
 
         # Wait for the units to be up before waiting for rel stability.
         if rels_created:
             self.log.debug(
-                "Waiting for relation convergence %ds", self.options.rel_wait)
-            time.sleep(self.options.rel_wait)
-            self.wait_for_units(self.options.retry_count)
+                "Waiting for relation convergence %ds", options.rel_wait)
+            time.sleep(options.rel_wait)
+            self.wait_for_units(ignore_errors=ignore_errors)
 
-        if self.options.retry_count:
+        if options.retry_count:
             self.log.info("Looking for errors to auto-retry")
             self.env.resolve_errors(
-                self.options.retry_count,
-                self.options.timeout - time.time() - self.start_time)
+                options.retry_count,
+                options.timeout - time.time() - self.start_time)
