@@ -87,6 +87,10 @@ def setup_parser():
         help=('Override *all* config options of the same name '
               'across all services.  Input as key=value.'),
         dest='overrides', default=None)
+    parser.add_argument(
+        '--series', type=str,
+        help=('Override distro series in config files'),
+        dest='series', default=None)
     parser.add_argument(
         '-v', '--verbose', action='store_true', default=False,
         dest="verbose", help='Verbose output')
@@ -97,6 +101,10 @@ def setup_parser():
         '-r', "--retry", default=0, type=int, dest="retry_count",
         help=("Resolve CLI and unit errors via number of retries (default: 0)."
               " Either standalone or in a deployment"))
+    parser.add_argument(
+        '--ignore-errors', action='store_true', dest='ignore_errors',
+        help='Proceed with the bundle deployment ignoring units errors. '
+             'Unit errors are also automatically ignored if --retry != 0')
     parser.add_argument(
         "--diff", action="store_true", default=False,
         help=("Generate a delta between a configured deployment and a running"
@@ -148,7 +156,7 @@ def run():
         sys.exit(1)
     log.debug('Using runtime %s', env.__class__.__name__)
 
-    config = ConfigStack(options.configs or [])
+    config = ConfigStack(options.configs or [], options.series)
 
     # Destroy services and exit
     if options.destroy_services or options.terminate_machines:
