@@ -12,9 +12,13 @@ See <https://code.launchpad.net/~juju-gui/charms/precise/juju-gui/trunk>.
 import os
 
 from deployer.action.importer import Importer
+from deployer.cli import setup_parser
 from deployer.deployment import Deployment
 from deployer.env.gui import GUIEnvironment
-from deployer.utils import mkdir
+from deployer.utils import (
+    DeploymentError,
+    mkdir,
+)
 
 
 # This value is used by the juju-deployer Importer object to store charms.
@@ -23,15 +27,11 @@ from deployer.utils import mkdir
 JUJU_HOME = '/var/lib/juju-gui/juju-home'
 
 
-class DeploymentError(Exception):
-    """One or more errors occurred during the deployment preparation."""
-
-    def __init__(self, errors):
-        self.errors = errors
-        super(DeploymentError, self).__init__(errors)
-
-    def __str__(self):
-        return '\n'.join(self.errors)
+def get_default_guiserver_options():
+    """Return the default importer options used by the GUI server."""
+    # Options used by the juju-deployer.  The defaults work for us, except for
+    # the ignore_errors flag.
+    return setup_parser().parse_args(['--ignore-errors'])
 
 
 class GUIDeployment(Deployment):
