@@ -10,14 +10,57 @@ import unittest
 import mock
 import yaml
 
-from deployer import (
-    cli,
-    guiserver,
-)
+from deployer import guiserver
 from deployer.feedback import Feedback
 from deployer.tests.base import TEST_OFFLINE
 
 
+class TestGetDefaultGuiserverOptions(unittest.TestCase):
+
+    def setUp(self):
+        self.options = guiserver.get_default_guiserver_options()
+
+    def test_option_keys(self):
+        # All the required options are returned.
+        # When adding/modifying options, ensure the defaults are sane for us.
+        expected_keys = set([
+            'bootstrap', 'branch_only', 'configs', 'debug', 'deploy_delay',
+            'deployment', 'description', 'destroy_services', 'diff',
+            'find_service', 'ignore_errors', 'juju_env', 'list_deploys',
+            'no_local_mods', 'overrides', 'rel_wait', 'retry_count', 'series',
+            'terminate_machines', 'timeout', 'update_charms', 'verbose',
+            'watch'
+        ])
+        self.assertEqual(expected_keys, set(self.options.__dict__.keys()))
+
+    def test_option_values(self):
+        # The options values are suitable to be used by the GUI server.
+        # When adding/modifying options, ensure the defaults are sane for us.
+        options = self.options
+        self.assertFalse(options.bootstrap)
+        self.assertFalse(options.branch_only)
+        self.assertIsNone(options.configs)
+        self.assertFalse(options.debug)
+        self.assertEqual(0, options.deploy_delay)
+        self.assertIsNone(options.deployment)
+        self.assertFalse(options.destroy_services)
+        self.assertFalse(options.diff)
+        self.assertIsNone(options.find_service)
+        self.assertTrue(options.ignore_errors)
+        self.assertEqual(os.getenv("JUJU_ENV"), options.juju_env)
+        self.assertFalse(options.list_deploys)
+        self.assertTrue(options.no_local_mods)
+        self.assertIsNone(options.overrides)
+        self.assertEqual(60, options.rel_wait)
+        self.assertEqual(0, options.retry_count)
+        self.assertIsNone(options.series)
+        self.assertFalse(options.terminate_machines)
+        self.assertEqual(2700, options.timeout)
+        self.assertFalse(options.update_charms)
+        self.assertFalse(options.verbose)
+        self.assertFalse(options.watch)
+
+
 class TestDeploymentError(unittest.TestCase):
 
     def test_error(self):
@@ -152,7 +195,7 @@ class TestValidate(DeployerFunctionsTestMixin, unittest.TestCase):
 class TestImportBundle(DeployerFunctionsTestMixin, unittest.TestCase):
 
     # The options attribute simulates the options passed to the Importer.
-    options = cli.setup_parser().parse_args([])
+    options = guiserver.get_default_guiserver_options()
 
     @contextmanager
     def patch_juju_home(self):
@@ -274,29 +317,3 @@ class TestImportBundle(DeployerFunctionsTestMixin, unittest.TestCase):
             'Invalid config charm cs:precise/mysql-28 bad=wolf',
         ])
         self.assertEqual(expected_errors, set(cm.exception.errors))
-
-    def test_options(self, mock_environment):
-        # Ensure the default options are sane for us.
-        expected = argparse.Namespace(
-            bootstrap=False,
-            branch_only=False,
-            configs=None,
-            debug=False,
-            deploy_delay=0,
-            deployment=None,
-            description=False,
-            destroy_services=False,
-            diff=False,
-            find_service=None,
-            juju_env=os.environ.get("JUJU_ENV"),
-            list_deploys=False,
-            no_local_mods=True,
-            overrides=None,
-            rel_wait=60,
-            retry_count=0,
-            terminate_machines=False,
-            timeout=2700,
-            update_charms=False,
-            verbose=False,
-            watch=False)
-        self.assertEqual(expected, self.options)
