@@ -1,14 +1,23 @@
 import os
+from StringIO import StringIO
 from subprocess import CalledProcessError
 
-from mock import patch, MagicMock
+from mock import (
+    MagicMock,
+    patch,
+)
 
 from .base import Base
 from deployer.utils import (
     _check_call,
+    _is_qualified_charm_url,
+    DeploymentError,
     dict_merge,
     ErrorExit,
+    get_qualified_charm_url,
+    HTTPError,
     mkdir,
+    URLError,
 )
 
 
@@ -41,7 +50,8 @@ class UtilTests(Base):
         _e = CalledProcessError(returncode=1, cmd=['fail'])
         check_output.side_effect = _e
         self.assertRaises(
-            ErrorExit, _check_call, params=['fail'], log=MagicMock(), max_retry=3)
+            ErrorExit, _check_call, params=['fail'], log=MagicMock(),
+            max_retry=3)
         # 1 failure + 3 retries
         self.assertEquals(len(check_output.call_args_list), 4)
 
@@ -104,3 +114,62 @@ class TestMkdir(Base):
         with self.assertRaises(OSError):
             mkdir(os.path.join(path))
         self.assertFalse(os.path.exists(path))
+
+
+class TestCharmRevisioning(Base):
+    """Test the functions related to charm URL revisioning."""
+
+    def test_is_qualified_false(self):
+        url = "cs:precise/mysql"
+        self.assertFalse(_is_qualified_charm_url(url))
+
+    def test_is_qualified_1_digit(self):
+        url = "cs:precise/mysql-2"
+        self.assertTrue(_is_qualified_charm_url(url))
+
+    def test_is_qualified_many_digits(self):
+        url = "cs:precise/mysql-2014"
+        self.assertTrue(_is_qualified_charm_url(url))
+
+    def test_is_qualified_no_digits(self):
+        url = "cs:precise/mysql-"
+        self.assertFalse(_is_qualified_charm_url(url))
+
+
+    def test_get_qualified_url(self):
+        fake_json = """
+          {"cs:precise/mysql":
+            {"revision":333}
+          }
+        """
+        def mocked_urlopen(url):
+            return StringIO(fake_json)
+
+        path = 'deployer.utils.urlopen'
+        with patch(path, mocked_urlopen):
+            url = get_qualified_charm_url('cs:precise/mysql')
+        self.assertEqual('cs:precise/mysql-333', url)
+
+    def test_get_qualified_url_raise_exception_on_HTTPError(self):
+        def mocked_urlopen(url):
+            raise HTTPError(url, 404, 'Bad Earl', None, None)
+
+        with patch('deployer.utils.urlopen', mocked_urlopen):
+            with self.assertRaises(DeploymentError) as exc:
+                get_qualified_charm_url('cs:precise/mysql')
+            expected = ('HTTP Error 404: '
+                        'Bad Earl (https://store.juju.ubuntu.com/charm-info'
+                        '?charms=cs:precise/mysql)')
+            self.assertEqual([expected], exc.exception.message)
+
+    def test_get_qualified_url_raise_exception_on_URLError(self):
+        def mocked_urlopen(url):
+            raise URLError('Hinky URL')
+
+        with patch('deployer.utils.urlopen', mocked_urlopen):
+            with self.assertRaises(DeploymentError) as exc:
+                get_qualified_charm_url('cs:precise/mysql')
+            expected = ('<urlopen error Hinky URL> '
+                        '(https://store.juju.ubuntu.com/charm-info'
+                        '?charms=cs:precise/mysql)')
+            self.assertEqual([expected], exc.exception.message)
