@@ -5,6 +5,7 @@ import errno
 import logging
 from logging.config import dictConfig as logConfig
 
+import json
 import os
 from os.path import (
     abspath,
@@ -19,6 +20,11 @@ import stat
 import subprocess
 import time
 import tempfile
+from urllib2 import (
+    HTTPError,
+    URLError,
+    urlopen,
+)
 import zipfile
 
 try:
@@ -35,9 +41,22 @@ class ErrorExit(Exception):
     def __init__(self, error=None):
         self.error = error
 
+
+class DeploymentError(Exception):
+    """One or more errors occurred during the deployment preparation."""
+
+    def __init__(self, errors):
+        self.errors = errors
+        super(DeploymentError, self).__init__(errors)
+
+    def __str__(self):
+        return '\n'.join(self.errors)
+
+
+STORE_URL = "https://store.juju.ubuntu.com"
+
+
 # Utility functions
-
-
 def yaml_dump(value):
     return yaml.dump(value, default_flow_style=False)
 
@@ -306,3 +325,28 @@ def mkdir(path):
         # Re-raise the error if the target path exists but it is not a dir.
         if (err.errno != errno.EEXIST) or (not isdir(path)):
             raise
+
+
+def _is_qualified_charm_url(url):
+    """Test an URL to see if it is revisioned."""
+    parts = url.rsplit('-', 1)
+    return len(parts) > 1 and parts[-1].isdigit()
+
+
+def get_qualified_charm_url(url):
+    """Given a charm URL, if not revisioned, return the latest revisioned URL.
+
+    If the URL is already revisioned, return it.
+    Otherwise ask the Charm store for the latest revision and return that URL.
+    """
+    if _is_qualified_charm_url(url):
+        return url
+    info_url = "%s/charm-info?charms=%s" % (STORE_URL, url)
+    try:
+        fh = urlopen(info_url)
+    except (HTTPError, URLError) as e:
+        errmsg = '{} ({})'.format(e, info_url)
+        raise DeploymentError([errmsg])
+    content = json.loads(fh.read())
+    rev = content[url]['revision']
+    return "%s-%d" % (url, rev)
